@@ -1,5 +1,7 @@
 """
-Main interface for appsync service literal definitions.
+Type annotations for appsync service literal definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/literals.html)
 
 Usage::
 
